@@ -21,7 +21,6 @@ package org.apache.maven.doxia.index;
 
 import java.util.List;
 import java.util.ArrayList;
-import java.util.Iterator;
 import java.util.Collections;
 
 import org.codehaus.plexus.util.StringUtils;
@@ -30,23 +29,32 @@ import org.codehaus.plexus.util.StringUtils;
  * <p>IndexEntry class.</p>
  *
  * @author <a href="mailto:trygvis@inamo.no">Trygve Laugst&oslash;l</a>
- * @version $Id: IndexEntry.java 807625 2009-08-25 13:43:52Z vsiveton $
  */
 public class IndexEntry
 {
-    /** The parent entry. */
+    /**
+     * The parent entry.
+     */
     private final IndexEntry parent;
 
-    /** The id of the entry. */
+    /**
+     * The id of the entry.
+     */
     private String id;
 
-    /** The entry title. */
+    /**
+     * The entry title.
+     */
     private String title;
 
-    /** The child entries. */
-    private List childEntries = new ArrayList();
+    /**
+     * The child entries.
+     */
+    private List<IndexEntry> childEntries = new ArrayList<>();
 
-    /** System-dependent EOL. */
+    /**
+     * System-dependent EOL.
+     */
     private static final String EOL = System.getProperty( "line.separator" );
 
     /**
@@ -63,7 +71,7 @@ public class IndexEntry
      * Constructor.
      *
      * @param newParent The parent. May be null.
-     * @param newId The id. May be null.
+     * @param newId     The id. May be null.
      */
     public IndexEntry( IndexEntry newParent, String newId )
     {
@@ -99,6 +107,7 @@ public class IndexEntry
     /**
      * Set the id.
      *
+     * @param id the id
      * @since 1.1.2
      */
     protected void setId( String id )
@@ -131,7 +140,7 @@ public class IndexEntry
      *
      * @return child entries.
      */
-    public List getChildEntries()
+    public List<IndexEntry> getChildEntries()
     {
         return Collections.unmodifiableList( childEntries );
     }
@@ -141,11 +150,11 @@ public class IndexEntry
      *
      * @param entries the entries.
      */
-    public void setChildEntries( List entries )
+    public void setChildEntries( List<IndexEntry> entries )
     {
         if ( entries == null )
         {
-            childEntries = new ArrayList();
+            childEntries = new ArrayList<>();
         }
 
         this.childEntries = entries;
@@ -167,7 +176,7 @@ public class IndexEntry
             return null;
         }
 
-        List entries = parent.getChildEntries();
+        List<IndexEntry> entries = parent.getChildEntries();
 
         int index = entries.indexOf( this );
 
@@ -176,7 +185,7 @@ public class IndexEntry
             return null;
         }
 
-        return (IndexEntry) entries.get( index + 1 );
+        return entries.get( index + 1 );
     }
 
     /**
@@ -191,7 +200,7 @@ public class IndexEntry
             return null;
         }
 
-        List entries = parent.getChildEntries();
+        List<IndexEntry> entries = parent.getChildEntries();
 
         int index = entries.indexOf( this );
 
@@ -200,7 +209,7 @@ public class IndexEntry
             return null;
         }
 
-        return (IndexEntry) entries.get( index - 1 );
+        return entries.get( index - 1 );
     }
 
     /**
@@ -210,14 +219,14 @@ public class IndexEntry
      */
     public IndexEntry getFirstEntry()
     {
-        List entries = getChildEntries();
+        List<IndexEntry> entries = getChildEntries();
 
         if ( entries.size() == 0 )
         {
             return null;
         }
 
-        return (IndexEntry) entries.get( 0 );
+        return entries.get( 0 );
     }
 
     /**
@@ -227,14 +236,14 @@ public class IndexEntry
      */
     public IndexEntry getLastEntry()
     {
-        List entries = getChildEntries();
+        List<IndexEntry> entries = getChildEntries();
 
         if ( entries.size() == 0 )
         {
             return null;
         }
 
-        return (IndexEntry) entries.get( entries.size() - 1 );
+        return entries.get( entries.size() - 1 );
     }
 
     /**
@@ -244,7 +253,7 @@ public class IndexEntry
      */
     public IndexEntry getRootEntry()
     {
-        List entries = getChildEntries();
+        List<IndexEntry> entries = getChildEntries();
 
         if ( entries.size() == 0 )
         {
@@ -256,7 +265,7 @@ public class IndexEntry
         }
         else
         {
-            return (IndexEntry) entries.get( 0 );
+            return entries.get( 0 );
         }
     }
 
@@ -265,9 +274,9 @@ public class IndexEntry
     // -----------------------------------------------------------------------
 
     /**
-     * {@inheritDoc}
-     *
      * Returns a string representation of the object.
+     *
+     * @return Returns a string representation of all objects
      */
     public String toString()
     {
@@ -282,7 +291,7 @@ public class IndexEntry
      */
     public String toString( int depth )
     {
-        StringBuffer message = new StringBuffer();
+        StringBuilder message = new StringBuilder();
 
         message.append( "Id: " ).append( id );
 
@@ -293,17 +302,15 @@ public class IndexEntry
 
         message.append( EOL );
 
-        String indent = "";
+        StringBuilder indent = new StringBuilder();
 
         for ( int i = 0; i < depth; i++ )
         {
-            indent += " ";
+            indent.append( " " );
         }
 
-        for ( Iterator it = getChildEntries().iterator(); it.hasNext(); )
+        for ( IndexEntry entry : getChildEntries() )
         {
-            IndexEntry entry = (IndexEntry) it.next();
-
             message.append( indent ).append( entry.toString( depth + 1 ) );
         }
 
